@@ -7,15 +7,15 @@ test_that("Barplot customEvents", {
     x <- read.table(system.file("extdata", "cX-generic-smp.txt", package = "canvasXpress"), header = TRUE, sep = "\t", quote = "", row.names = 1, fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
     z <- read.table(system.file("extdata", "cX-generic-var.txt", package = "canvasXpress"), header = TRUE, sep = "\t", quote = "", row.names = 1, fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
 
-    events <- heatmap_events <- JS("{ 'mousemove' : function(o, e, t) {
-                                                if (o.objectType == null) {
-                                                  t.showInfoSpan(e, '<b>' + o.y.vars[0] + '</b><br/>' +
-                                                  'Sample:' + o.y.smps[0] +  '<br/>' +
-                                                  '<i>Value:</i>' +  o.y.data[0][0]);
-                                                }
-                                                else {
-                                                  t.showInfoSpan(e, o.display);
-                                                };
+    events <- JS("{ 'mousemove' : function(o, e, t) {
+                                    if (o.objectType == null) {
+                                      t.showInfoSpan(e, '<b>' + o.y.vars[0] + '</b><br/>' +
+                                      'Sample:' + o.y.smps[0] +  '<br/>' +
+                                      '<i>Value:</i>' +  o.y.data[0][0]);
+                                    }
+                                    else {
+                                      t.showInfoSpan(e, o.display);
+                                    };
                                    }}")
     result <-  canvasXpress(
         data                    = y,
